<?php
/**
 * Firecall Agents Setting Settings
 *
 * @package Firecall\Admin
 */

defined( 'ABSPATH' ) || exit;

if ( class_exists( 'Firecall_Settings_Agentsetting', false ) ) {
	return new Firecall_Settings_Agentsetting();
}
include_once dirname( __FILE__ ) . '/class-firecall-setting-page.php';

/**
 * Firecall_Admin_Settings_Agents.
 */
class Firecall_Settings_Agentsetting extends Firecall_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'agentsetting';
		$this->label = esc_html__( 'Agent Settings', 'firecall' );

		parent::__construct();
	}

	/**
	 * Get settings or the default section.
	 *
	 * @return array
	 */
	protected function get_settings_for_default_section() {
		
		$settings =
		array(

			array(
				'title' => esc_html__( 'Agent Settings', 'firecall' ),
				'type'  => 'title',
				'desc'  => wp_kses_post( '', 'firecall' ),
				'id'    => 'firecall_agent_settings',
				'desc_tip' => false,
			),

			array(
				'title'    => esc_html__( 'Agent Thumbnail', 'firecall' ),
				'desc'     => esc_html__( '', 'firecall' ),
				'id'       => 'firecall_agent_thumbnail_enable',
				'default'  => esc_html__('unable', 'firecall'),
				'unable'   => esc_html__('Show', 'firecall'),
				'disable'  => esc_html__('Hide', 'firecall'),
				'class'    => 'switch_box',
				'type'     => 'switchbox',
				'desc_tip' => esc_html__( '', 'firecall' ),
			),

			array(
				'title'    => esc_html__( 'Agent Name', 'firecall' ),
				'desc'     => esc_html__( '', 'firecall' ),
				'id'       => 'firecall_agent_name_enable',
				'default'  => esc_html__('unable', 'firecall'),
				'unable'   => esc_html__('Show', 'firecall'),
				'disable'  => esc_html__('Hide', 'firecall'),
				'class'    => 'switch_box',
				'type'     => 'switchbox',
				'desc_tip' => esc_html__( '', 'firecall' ),
			),

			array(
				'title'    => esc_html__( 'Agent Position', 'firecall' ),
				'desc'     => esc_html__( '', 'firecall' ),
				'id'       => 'firecall_agent_position_enable',
				'default'  => esc_html__('unable', 'firecall'),
				'unable'   => esc_html__('Show', 'firecall'),
				'disable'  => esc_html__('Hide', 'firecall'),
				'class'    => 'switch_box',
				'type'     => 'switchbox',
				'desc_tip' => esc_html__( '', 'firecall' ),
			),

			array(
				'title'    => esc_html__( 'Agent Description', 'firecall' ),
				'desc'     => esc_html__( '', 'firecall' ),
				'id'       => 'firecall_agent_description_enable',
				'default'  => esc_html__('unable', 'firecall'),
				'unable'   => esc_html__('Show', 'firecall'),
				'disable'  => esc_html__('Hide', 'firecall'),
				'class'    => 'switch_box',
				'type'     => 'switchbox',
				'desc_tip' => esc_html__( '', 'firecall' ),
			),

			array(
				'title'     => esc_html__( 'Agent Name Color', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_agent_name_color',
				'default'   => esc_attr('#FC3A52'),
				'desc_tip'  => true,
				'type'      => 'color',
			),	

			array(
				'title'     => esc_html__( 'Agent Position Color', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_agent_position_color',
				'default'   => esc_attr('#000000'),
				'desc_tip'  => true,
				'type'      => 'color',
			),	

			array(
				'title'     => esc_html__( 'Agent Description Color', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_agent_desc_color',
				'default'   => esc_attr('#000000'),
				'desc_tip'  => true,
				'type'      => 'color',
			),

			array(
				'title'     => esc_html__( 'Agent Telephone Color', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_agent_telephone_color',
				'default'   => esc_attr('#FC3A52'),
				'desc_tip'  => true,
				'type'      => 'color',
			),

			array(
				'title'    => esc_html__( 'Agent Card Layouts', 'firecall' ),
				'desc'     => esc_html__( 'This option lets you set layout for agents.', 'firecall' ),
				'id'       => 'firecall_agent_card_layout',
				'default'  => esc_attr('1'),
				'type'     => 'select',
				'class'    => 'firecall-enhanced-select',
				'css'      => 'min-width: 350px;',
				'desc_tip' => true,
				'options'  => array(
					'1'        => array(esc_html__( 'Layout 1', 'firecall' ), esc_url(FIRECALL_PLUGIN_FILE.'images/agent-layout-1.png')),
					'2'        => array(esc_html__( 'Layout 2', 'firecall' ), esc_url(FIRECALL_PLUGIN_FILE.'images/agent-layout-2.png')),
					'3'        => array(esc_html__( 'Layout 3', 'firecall' ), esc_url(FIRECALL_PLUGIN_FILE.'images/agent-layout-3.png')),
					'4'        => array(esc_html__( 'Layout 4', 'firecall' ), esc_url(FIRECALL_PLUGIN_FILE.'images/agent-layout-4.png')),
					'5'        => array(esc_html__( 'Layout 5', 'firecall' ), esc_url(FIRECALL_PLUGIN_FILE.'images/agent-layout-5.png')),
					'6'        => array(esc_html__( 'Layout 6', 'firecall' ), esc_url(FIRECALL_PLUGIN_FILE.'images/agent-layout-6.png')),
				),
			),
			array(
				'title'    => esc_html__( '', 'firecall' ),
				'desc'     => esc_html__( 'This Preview is for layout.', 'firecall' ),
				'id'       => 'firecall_agent_card_layout_preview',
				'type'     => 'preview_design',
				'class'    => 'firecall-preview-design',
				'desc_tip' => true,
			),

			array(
				'type' => 'sectionend',
				'id'   => 'firecall_agent_settings',
			),
		);

return apply_filters( 'firecall_agents_settings', $settings );
}

}

return new Firecall_Settings_Agentsetting();