<?php
/**
 * Firecall Agents Setting Settings
 *
 * @package Firecall\Admin
 */

defined( 'ABSPATH' ) || exit;

if ( class_exists( 'Firecall_Settings_Callsetting', false ) ) {
	return new Firecall_Settings_Callsetting();
}
include_once dirname( __FILE__ ) . '/class-firecall-setting-page.php';

/**
 * Firecall_Admin_Settings_Agents.
 */
class Firecall_Settings_Callsetting extends Firecall_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = esc_attr('callsetting');
		$this->label = esc_html__( 'Call Settings', 'firecall' );

		parent::__construct();
	}

	/**
	 * Get settings or the default section.
	 *
	 * @return array
	 */
	protected function get_settings_for_default_section() {
		
		$settings =
		array(

			array(
				'title' => esc_html__( 'Call Settings', 'firecall' ),
				'type'  => 'title',
				'desc'  => wp_kses_post( '', 'firecall' ),
				'id'    => 'firecall_call_settings',
				'desc_tip' => false,
			),
			array(
				'title'    => esc_html__( 'Icon', 'firecall' ),
				'desc'     => esc_html__( '', 'firecall' ),
				'id'       => 'firecall_call_icon_enable',
				'default'  => esc_attr('unable', 'firecall'),
				'unable'   => esc_html__('Show', 'firecall'),
				'disable'  => esc_html__('Hide', 'firecall'),
				'class'    => 'switch_box',
				'type'     => 'switchbox',
				'desc_tip' => esc_html__( '', 'firecall' ),
			),
			array(
				'title'    => esc_html__( 'Text', 'firecall' ),
				'desc'     => esc_html__( '', 'firecall' ),
				'id'       => 'firecall_title_enable',
				'default'  => esc_attr('disable', 'firecall'),
				'unable'   => esc_html__('Show', 'firecall'),
				'disable'  => esc_html__('Hide', 'firecall'),
				'class'    => 'switch_box',
				'type'     => 'switchbox',
				'desc_tip' => esc_html__( '', 'firecall' ),
			),

			array(
				'title'    => esc_html__( 'Call Button Style', 'firecall' ),
				'desc'     => esc_html__( '', 'firecall' ),
				'id'       => 'firecall_call_button_style',
				'default'  => esc_attr('unable', 'firecall'),
				'unable'   => esc_html__('Fill', 'firecall'),
				'disable'  => esc_html__('Stroke', 'firecall'),
				'class'    => 'switch_box',
				'type'     => 'switchbox',
				'desc_tip' => esc_html__( '', 'firecall' ),
			),

			array(
				'title'     => esc_html__( 'Call Text', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_call_button_text',
				'default'   => esc_html__('Call Us', 'firecall'),
				'desc_tip'  => true,
				'type'      => 'text',
			),

			array(
				'title'     => esc_html__( 'Call Button Text and Icon Color', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_button_text_and_icon_color',
				'default'   => esc_attr('#FFFFFF'),
				'desc_tip'  => true,
				'type'      => 'color',
			),

			array(
				'title'     => esc_html__( 'Call Button Border Color', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_border_color',
				'default'   => esc_attr('#FC3A52'),
				'desc_tip'  => true,
				'type'      => 'color',
			),

			array(
				'title'     => esc_html__( 'Call Button Background Color', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_button_back_color',
				'default'   => esc_attr('#FC3A52'),
				'desc_tip'  => true,
				'type'      => 'color',
			),

			array(
				'title'     => esc_html__( 'Call Button Icons', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_agent_layout',
				'type'      => 'fcradio',
				'default'      => esc_attr( 'Icon 1'),
				'options'   => array(
					'Icon 1' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-1.svg">'),
					'Icon 2' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-2.svg">'),
					'Icon 3' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-3.svg">'),
					'Icon 4' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-4.svg">'),
					'Icon 5' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-5.svg">'),
					'Icon 6' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-6.svg">'),
					'Icon 7' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-7.svg">'),
					'Icon 8' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-8.svg">'),
					'Icon 9' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-9.svg">'),
					'Icon 10' => wp_kses_post('<img class="call-icon-image" src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-icons-svg/call-icon-layout-10.svg">'),
				)
			),
			array(
				'title'     => esc_html__( 'Call Button Shape', 'firecall' ),
				'desc'      => esc_html__( '', 'firecall' ),
				'id'        => 'firecall_call_button_shape',
				'type'      => 'fcradio',
				'default'   => esc_attr( 'shape_one' ),
				'options'   => array(
					'shape_one' => wp_kses_post('<img src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-shape-svg/call-button-shape-1.svg">'),
					'shape_two' => wp_kses_post('<img src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-shape-svg/call-button-shape-2.svg">'),
					'shape_three' => wp_kses_post('<img src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-shape-svg/call-button-shape-3.svg">'),
					'shape_four' => wp_kses_post('<img src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-shape-svg/call-button-shape-4.svg">'),
					'shape_five' => wp_kses_post('<img src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-shape-svg/call-button-shape-5.svg">'),
					'shape_six' => wp_kses_post('<img src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-shape-svg/call-button-shape-6.svg">'),
					'shape_seven' => wp_kses_post('<img src="'.FIRECALL_PLUGIN_FILE.'public/assets/call-shape-svg/call-button-shape-7.svg">'),
				)
			),
			array(
				'type' => 'sectionend',
				'id'   => 'firecall_call_settings',
			),
		);

return apply_filters( 'firecall_agents_settings', $settings );
}

}

return new Firecall_Settings_Callsetting();