<?php
/**
 * The public-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-specific stylesheet and JavaScript.
 *
 * @package    Firecall
 * @subpackage Firecall/public
 * @author     The_Krishna
 */
class Firecall_Public {

	public $fill_stroke; 

	public $fill_color;

	public $icon_btn_text_color;

	public $fc_theme_color;

	public $fc_stroke_color;

	public $call_icon_enable;

	public $call_text_enable;

	public $call_btn_text;

	public $call_layout;

	public $agent_layout;

	public $agent_lists;

	public $agent_card_layout;

	public $fc_agent_thumb_enable;

	public $fc_agent_name_enable;

	public $fc_agent_position_enable;

	public $fc_agent_desc_enable;

	public $agent_name_color;

	public $agent_position_color;

	public $agent_desc_color;

	public $agent_telephone_color;
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		add_action( 'wp_enqueue_scripts', array($this, 'add_firecall_public_scripts_func') );
		add_action('wp_footer', array($this, 'firecaller_widget_func'), 1);
		add_action('wp_head', array($this, 'add_firecall_custom_style_func'));

		$this->agent_lists = get_option('firecall_agent_list');
		$this->agent_card_layout = esc_attr(get_option('firecall_agent_card_layout')?:1);

		// variables for agent data show/hide

		$this->fc_agent_thumb_enable = esc_attr((get_option('firecall_agent_thumbnail_enable'))?:'unable');
		$this->fc_agent_name_enable = esc_attr((get_option('firecall_agent_name_enable'))?:'unable');
		$this->fc_agent_position_enable = esc_attr((get_option('firecall_agent_position_enable'))?:'unable');
		$this->fc_agent_desc_enable = esc_attr((get_option('firecall_agent_description_enable'))?:'unable');


		// agent color options
		$this->agent_name_color = esc_attr(get_option('firecall_agent_name_color')?:'#FC3A52');
		$this->agent_position_color = esc_attr(get_option('firecall_agent_position_color')?:'#000000');
		$this->agent_desc_color = esc_attr(get_option('firecall_agent_desc_color')?:'#000000');
		$this->agent_telephone_color = esc_attr(get_option('firecall_agent_telephone_color')?:'#FC3A52');

		// button styling options
		$this->fill_stroke = esc_attr((get_option('firecall_call_button_style'))?:'unable');
		$this->fill_color = esc_attr((get_option('firecall_button_back_color'))?:'#FC3A52');
		$this->icon_btn_text_color = esc_attr((get_option('firecall_button_text_and_icon_color'))?:'#FFFFFF');
		$this->fc_stroke_color = esc_attr((get_option('firecall_border_color'))?:'#FC3A52');

		// call icon layout
		$this->call_icon_enable = esc_attr(get_option('firecall_call_icon_enable')?:'unable');
		$this->call_text_enable = esc_attr(get_option('firecall_title_enable')?:'disable');
		$this->call_btn_text = esc_attr(get_option('firecall_call_button_text')?:'Call Us');
		$this->call_layout = esc_attr(get_option('firecall_call_button_shape')?:'shape_one');

		$this->agent_layout = esc_attr(get_option('firecall_agent_layout')?:'Icon 1');
	}

	  /**
 	  * Enqueue a script with jQuery as a dependency.
 	  */

	  public function add_firecall_public_scripts_func( $hook_suffix ) {

	  	global $wp_query;

	  	$version = FIRECALL_VERSION;

	 	 // first check that $hook_suffix is appropriate for your public page

	  	wp_enqueue_style( 'blogsqode-public-styles', plugins_url( '/assets/css/firecall-public.css', __FILE__ ), array(), $version, 'all' );

	  	wp_enqueue_script('jquery');

	  	wp_enqueue_script( 'blogsqode-public-scripts', plugins_url('/assets/js/firecall-public.js', __FILE__ ), array( 'jquery' ), $version );

	  }


	 /**
	 * Check if the current user has access to backend / frontend based on his role compared with role from settings (refactor @ 2.0.4)
	 *
	 * @since 1.0.0
	 * @return html
	 */

	 public function firecaller_widget_func() {
	 	ob_start();
	 	?>
	 	<div class='firecall_widgets'>

	 		<?php if($this->agent_layout === 'Icon 1'){
	 			$this->firecall_icon_wise_html_func('call_button_lyt_1', '<svg width="24" height="24" viewBox="0 0 24 24" fill="'.$this->icon_btn_text_color.'" xmlns="http://www.w3.org/2000/svg"><g clip-path="url(#clip0_7_119)"><path d="M17.4 22C13.3173 21.9947 9.40331 20.3705 6.5164 17.4836C3.62949 14.5967 2.00529 10.6827 2 6.6C2 5.38 2.48464 4.20998 3.34731 3.34731C4.20998 2.48464 5.38 2 6.6 2C6.85834 1.99803 7.11625 2.02148 7.37 2.07C7.61531 2.1063 7.85647 2.16659 8.09 2.25C8.25425 2.30763 8.40061 2.40713 8.51461 2.53867C8.62861 2.67021 8.7063 2.82923 8.74 3L10.11 9C10.1469 9.16286 10.1425 9.33238 10.0971 9.49308C10.0516 9.65379 9.96671 9.80056 9.85 9.92C9.72 10.06 9.71 10.07 8.48 10.71C9.46499 12.8709 11.1932 14.6062 13.35 15.6C14 14.36 14.01 14.35 14.15 14.22C14.2694 14.1033 14.4162 14.0184 14.5769 13.9729C14.7376 13.9275 14.9071 13.9231 15.07 13.96L21.07 15.33C21.2353 15.3684 21.3881 15.4481 21.5141 15.5619C21.64 15.6756 21.735 15.8195 21.79 15.98C21.8744 16.2174 21.938 16.4616 21.98 16.71C22.0202 16.9613 22.0403 17.2155 22.04 17.47C22.0216 18.6848 21.5233 19.8429 20.654 20.6917C19.7847 21.5404 18.6149 22.0107 17.4 22Z" fill="'.$this->icon_btn_text_color.'"/></g><defs><clipPath id="clip0_7_119"><rect width="24" height="24" fill="'.$this->icon_btn_text_color.'"/></clipPath></defs></svg>');

	 		} else if($this->agent_layout === 'Icon 2'){

	 			$this->firecall_icon_wise_html_func('call_button_lyt_2', '<svg width="24" height="24" viewBox="0 0 24 24" fill="'.$this->icon_btn_text_color.'" xmlns="http://www.w3.org/2000/svg"><g clip-path="url(#clip0_7_124)"><path d="M13 8C13.7956 8 14.5587 8.31607 15.1213 8.87868C15.6839 9.44129 16 10.2044 16 11C16 11.2652 16.1054 11.5196 16.2929 11.7071C16.4804 11.8946 16.7348 12 17 12C17.2652 12 17.5196 11.8946 17.7071 11.7071C17.8946 11.5196 18 11.2652 18 11C18 9.67392 17.4732 8.40215 16.5355 7.46447C15.5979 6.52678 14.3261 6 13 6C12.7348 6 12.4804 6.10536 12.2929 6.29289C12.1054 6.48043 12 6.73478 12 7C12 7.26522 12.1054 7.51957 12.2929 7.70711C12.4804 7.89464 12.7348 8 13 8Z" fill="'.$this->icon_btn_text_color.'"/><path d="M13 4C14.8565 4 16.637 4.7375 17.9497 6.05025C19.2625 7.36301 20 9.14348 20 11C20 11.2652 20.1054 11.5196 20.2929 11.7071C20.4804 11.8946 20.7348 12 21 12C21.2652 12 21.5196 11.8946 21.7071 11.7071C21.8946 11.5196 22 11.2652 22 11C22 8.61305 21.0518 6.32387 19.364 4.63604C17.6761 2.94821 15.3869 2 13 2C12.7348 2 12.4804 2.10536 12.2929 2.29289C12.1054 2.48043 12 2.73478 12 3C12 3.26522 12.1054 3.51957 12.2929 3.70711C12.4804 3.89464 12.7348 4 13 4Z" fill="'.$this->icon_btn_text_color.'"/><path d="M21.75 15.91C21.695 15.7495 21.6 15.6056 21.4741 15.4919C21.3481 15.3781 21.1953 15.2984 21.03 15.26L15.03 13.89C14.8671 13.8531 14.6976 13.8575 14.5369 13.9029C14.3762 13.9484 14.2294 14.0333 14.11 14.15C13.97 14.28 13.96 14.29 13.31 15.53C11.1532 14.5362 9.42499 12.8009 8.44 10.64C9.71 10 9.72 10 9.85 9.85C9.96671 9.73056 10.0516 9.58379 10.0971 9.42308C10.1425 9.26238 10.1469 9.09286 10.11 8.93L8.74 3C8.70165 2.8347 8.62186 2.68187 8.50814 2.55591C8.39443 2.42995 8.25053 2.335 8.09 2.28C7.85647 2.19659 7.61531 2.1363 7.37 2.1C7.11725 2.0414 6.85933 2.0079 6.6 2C5.38 2 4.20998 2.48464 3.34731 3.34731C2.48464 4.20998 2 5.38 2 6.6C2.00529 10.6827 3.62949 14.5967 6.5164 17.4836C9.40331 20.3705 13.3173 21.9947 17.4 22C18.0041 22 18.6022 21.881 19.1603 21.6498C19.7184 21.4187 20.2255 21.0798 20.6527 20.6527C21.0798 20.2255 21.4187 19.7184 21.6498 19.1603C21.881 18.6022 22 18.0041 22 17.4C22.0003 17.1455 21.9802 16.8913 21.94 16.64C21.898 16.3916 21.8344 16.1474 21.75 15.91Z" fill="'.$this->icon_btn_text_color.'"/></g><defs><clipPath id="clip0_7_124"><rect width="24" height="24" fill="'.$this->icon_btn_text_color.'"/></clipPath></defs></svg>');
	 			
	 		} else if($this->agent_layout === 'Icon 3'){

	 			$this->firecall_icon_wise_html_func('call_button_lyt_3', '<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M11.05 14.95L9.2 16.8C8.81 17.19 8.19 17.19 7.79 16.81C7.68 16.7 7.57 16.6 7.46 16.49C6.43 15.45 5.5 14.36 4.67 13.22C3.85 12.08 3.19 10.94 2.71 9.81C2.24 8.67 2 7.58 2 6.54C2 5.86 2.12 5.21 2.36 4.61C2.6 4 2.98 3.44 3.51 2.94C4.15 2.31 4.85 2 5.59 2C5.87 2 6.15 2.06 6.4 2.18C6.66 2.3 6.89 2.48 7.07 2.74L9.39 6.01C9.57 6.26 9.7 6.49 9.79 6.71C9.88 6.92 9.93 7.13 9.93 7.32C9.93 7.56 9.86 7.8 9.72 8.03C9.59 8.26 9.4 8.5 9.16 8.74L8.4 9.53C8.29 9.64 8.24 9.77 8.24 9.93C8.24 10.01 8.25 10.08 8.27 10.16C8.3 10.24 8.33 10.3 8.35 10.36C8.53 10.69 8.84 11.12 9.28 11.64C9.73 12.16 10.21 12.69 10.73 13.22C10.83 13.32 10.94 13.42 11.04 13.52C11.44 13.91 11.45 14.55 11.05 14.95Z" fill="'.$this->icon_btn_text_color.'"/><path d="M21.97 18.33C21.97 18.61 21.92 18.9 21.82 19.18C21.79 19.26 21.76 19.34 21.72 19.42C21.55 19.78 21.33 20.12 21.04 20.44C20.55 20.98 20.01 21.37 19.4 21.62C19.39 21.62 19.38 21.63 19.37 21.63C18.78 21.87 18.14 22 17.45 22C16.43 22 15.34 21.76 14.19 21.27C13.04 20.78 11.89 20.12 10.75 19.29C10.36 19 9.97 18.71 9.6 18.4L12.87 15.13C13.15 15.34 13.4 15.5 13.61 15.61C13.66 15.63 13.72 15.66 13.79 15.69C13.87 15.72 13.95 15.73 14.04 15.73C14.21 15.73 14.34 15.67 14.45 15.56L15.21 14.81C15.46 14.56 15.7 14.37 15.93 14.25C16.16 14.11 16.39 14.04 16.64 14.04C16.83 14.04 17.03 14.08 17.25 14.17C17.47 14.26 17.7 14.39 17.95 14.56L21.26 16.91C21.52 17.09 21.7 17.3 21.81 17.55C21.91 17.8 21.97 18.05 21.97 18.33Z" fill="'.$this->icon_btn_text_color.'"/></svg>');

	 		} else if($this->agent_layout === 'Icon 4'){ 

	 			$this->firecall_icon_wise_html_func('call_button_lyt_4', '<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M17.62 10.75C17.19 10.75 16.85 10.4 16.85 9.98C16.85 9.61 16.48 8.84 15.86 8.17C15.25 7.52 14.58 7.14 14.02 7.14C13.59 7.14 13.25 6.79 13.25 6.37C13.25 5.95 13.6 5.6 14.02 5.6C15.02 5.6 16.07 6.14 16.99 7.11C17.85 8.02 18.4 9.15 18.4 9.97C18.4 10.4 18.05 10.75 17.62 10.75Z" fill="'.$this->icon_btn_text_color.'"/>
	 				<path d="M21.23 10.75C20.8 10.75 20.46 10.4 20.46 9.98C20.46 6.43 17.57 3.55 14.03 3.55C13.6 3.55 13.26 3.2 13.26 2.78C13.26 2.36 13.6 2 14.02 2C18.42 2 22 5.58 22 9.98C22 10.4 21.65 10.75 21.23 10.75Z" fill="'.$this->icon_btn_text_color.'"/><path d="M11.05 14.95L9.2 16.8C8.81 17.19 8.19 17.19 7.79 16.81C7.68 16.7 7.57 16.6 7.46 16.49C6.43 15.45 5.5 14.36 4.67 13.22C3.85 12.08 3.19 10.94 2.71 9.81C2.24 8.67 2 7.58 2 6.54C2 5.86 2.12 5.21 2.36 4.61C2.6 4 2.98 3.44 3.51 2.94C4.15 2.31 4.85 2 5.59 2C5.87 2 6.15 2.06 6.4 2.18C6.66 2.3 6.89 2.48 7.07 2.74L9.39 6.01C9.57 6.26 9.7 6.49 9.79 6.71C9.88 6.92 9.93 7.13 9.93 7.32C9.93 7.56 9.86 7.8 9.72 8.03C9.59 8.26 9.4 8.5 9.16 8.74L8.4 9.53C8.29 9.64 8.24 9.77 8.24 9.93C8.24 10.01 8.25 10.08 8.27 10.16C8.3 10.24 8.33 10.3 8.35 10.36C8.53 10.69 8.84 11.12 9.28 11.64C9.73 12.16 10.21 12.69 10.73 13.22C10.83 13.32 10.94 13.42 11.04 13.52C11.44 13.91 11.45 14.55 11.05 14.95Z" fill="'.$this->icon_btn_text_color.'"/><path d="M21.97 18.33C21.97 18.61 21.92 18.9 21.82 19.18C21.79 19.26 21.76 19.34 21.72 19.42C21.55 19.78 21.33 20.12 21.04 20.44C20.55 20.98 20.01 21.37 19.4 21.62C19.39 21.62 19.38 21.63 19.37 21.63C18.78 21.87 18.14 22 17.45 22C16.43 22 15.34 21.76 14.19 21.27C13.04 20.78 11.89 20.12 10.75 19.29C10.36 19 9.97 18.71 9.6 18.4L12.87 15.13C13.15 15.34 13.4 15.5 13.61 15.61C13.66 15.63 13.72 15.66 13.79 15.69C13.87 15.72 13.95 15.73 14.04 15.73C14.21 15.73 14.34 15.67 14.45 15.56L15.21 14.81C15.46 14.56 15.7 14.37 15.93 14.25C16.16 14.11 16.39 14.04 16.64 14.04C16.83 14.04 17.03 14.08 17.25 14.17C17.47 14.26 17.7 14.39 17.95 14.56L21.26 16.91C21.52 17.09 21.7 17.3 21.81 17.55C21.91 17.8 21.97 18.05 21.97 18.33Z" fill="'.$this->icon_btn_text_color.'"/></svg>');

	 		} else if($this->agent_layout === 'Icon 5'){

	 			$this->firecall_icon_wise_html_func('call_button_lyt_5', '	<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M21.97 18.33C21.97 18.69 21.89 19.06 21.72 19.42C21.55 19.78 21.33 20.12 21.04 20.44C20.55 20.98 20.01 21.37 19.4 21.62C18.8 21.87 18.15 22 17.45 22C16.43 22 15.34 21.76 14.19 21.27C13.04 20.78 11.89 20.12 10.75 19.29C9.6 18.45 8.51 17.52 7.47 16.49C6.44 15.45 5.51 14.36 4.68 13.22C3.86 12.08 3.2 10.94 2.72 9.81C2.24 8.67 2 7.58 2 6.54C2 5.86 2.12 5.21 2.36 4.61C2.6 4 2.98 3.44 3.51 2.94C4.15 2.31 4.85 2 5.59 2C5.87 2 6.15 2.06 6.4 2.18C6.66 2.3 6.89 2.48 7.07 2.74L9.39 6.01C9.57 6.26 9.7 6.49 9.79 6.71C9.88 6.92 9.93 7.13 9.93 7.32C9.93 7.56 9.86 7.8 9.72 8.03C9.59 8.26 9.4 8.5 9.16 8.74L8.4 9.53C8.29 9.64 8.24 9.77 8.24 9.93C8.24 10.01 8.25 10.08 8.27 10.16C8.3 10.24 8.33 10.3 8.35 10.36C8.53 10.69 8.84 11.12 9.28 11.64C9.73 12.16 10.21 12.69 10.73 13.22C11.27 13.75 11.79 14.24 12.32 14.69C12.84 15.13 13.27 15.43 13.61 15.61C13.66 15.63 13.72 15.66 13.79 15.69C13.87 15.72 13.95 15.73 14.04 15.73C14.21 15.73 14.34 15.67 14.45 15.56L15.21 14.81C15.46 14.56 15.7 14.37 15.93 14.25C16.16 14.11 16.39 14.04 16.64 14.04C16.83 14.04 17.03 14.08 17.25 14.17C17.47 14.26 17.7 14.39 17.95 14.56L21.26 16.91C21.52 17.09 21.7 17.3 21.81 17.55C21.91 17.8 21.97 18.05 21.97 18.33Z" stroke="'.$this->icon_btn_text_color.'" stroke-width="1.5" stroke-miterlimit="10"/></svg>');

	 		} else if($this->agent_layout === 'Icon 6'){ 

	 			$this->firecall_icon_wise_html_func('call_button_lyt_6', '	<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M21.97 18.33C21.97 18.69 21.89 19.06 21.72 19.42C21.55 19.78 21.33 20.12 21.04 20.44C20.55 20.98 20.01 21.37 19.4 21.62C18.8 21.87 18.15 22 17.45 22C16.43 22 15.34 21.76 14.19 21.27C13.04 20.78 11.89 20.12 10.75 19.29C9.6 18.45 8.51 17.52 7.47 16.49C6.44 15.45 5.51 14.36 4.68 13.22C3.86 12.08 3.2 10.94 2.72 9.81C2.24 8.67 2 7.58 2 6.54C2 5.86 2.12 5.21 2.36 4.61C2.6 4 2.98 3.44 3.51 2.94C4.15 2.31 4.85 2 5.59 2C5.87 2 6.15 2.06 6.4 2.18C6.66 2.3 6.89 2.48 7.07 2.74L9.39 6.01C9.57 6.26 9.7 6.49 9.79 6.71C9.88 6.92 9.93 7.13 9.93 7.32C9.93 7.56 9.86 7.8 9.72 8.03C9.59 8.26 9.4 8.5 9.16 8.74L8.4 9.53C8.29 9.64 8.24 9.77 8.24 9.93C8.24 10.01 8.25 10.08 8.27 10.16C8.3 10.24 8.33 10.3 8.35 10.36C8.53 10.69 8.84 11.12 9.28 11.64C9.73 12.16 10.21 12.69 10.73 13.22C11.27 13.75 11.79 14.24 12.32 14.69C12.84 15.13 13.27 15.43 13.61 15.61C13.66 15.63 13.72 15.66 13.79 15.69C13.87 15.72 13.95 15.73 14.04 15.73C14.21 15.73 14.34 15.67 14.45 15.56L15.21 14.81C15.46 14.56 15.7 14.37 15.93 14.25C16.16 14.11 16.39 14.04 16.64 14.04C16.83 14.04 17.03 14.08 17.25 14.17C17.47 14.26 17.7 14.39 17.95 14.56L21.26 16.91C21.52 17.09 21.7 17.3 21.81 17.55C21.91 17.8 21.97 18.05 21.97 18.33Z" stroke="'.$this->icon_btn_text_color.'" stroke-width="1.5" stroke-miterlimit="10"/><path d="M18.5 9C18.5 8.4 18.03 7.48 17.33 6.73C16.69 6.04 15.84 5.5 15 5.5" stroke="'.$this->icon_btn_text_color.'" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/><path d="M22 9C22 5.13 18.87 2 15 2" stroke="'.$this->icon_btn_text_color.'" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/></svg>');

	 		} else if($this->agent_layout === 'Icon 7'){

	 			$this->firecall_icon_wise_html_func('call_button_lyt_7', '<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M8.38028 8.85323C9.07627 10.3028 10.0251 11.6615 11.2266 12.8631C12.4282 14.0646 13.7869 15.0134 15.2365 15.7094C15.3612 15.7693 15.4235 15.7992 15.5024 15.8222C15.7828 15.904 16.127 15.8453 16.3644 15.6752C16.4313 15.6274 16.4884 15.5702 16.6027 15.4559C16.9523 15.1063 17.1271 14.9315 17.3029 14.8172C17.9658 14.3862 18.8204 14.3862 19.4833 14.8172C19.6591 14.9315 19.8339 15.1063 20.1835 15.4559L20.3783 15.6508C20.9098 16.1822 21.1755 16.448 21.3198 16.7333C21.6069 17.3009 21.6069 17.9712 21.3198 18.5387C21.1755 18.8241 20.9098 19.0898 20.3783 19.6213L20.2207 19.7789C19.6911 20.3085 19.4263 20.5733 19.0662 20.7756C18.6667 21 18.0462 21.1614 17.588 21.16C17.1751 21.1588 16.8928 21.0787 16.3284 20.9185C13.295 20.0575 10.4326 18.433 8.04466 16.045C5.65668 13.6571 4.03221 10.7947 3.17124 7.76131C3.01103 7.19687 2.93092 6.91464 2.9297 6.5017C2.92833 6.04347 3.08969 5.42298 3.31411 5.02348C3.51636 4.66345 3.78117 4.39863 4.3108 3.86901L4.46843 3.71138C4.99987 3.17993 5.2656 2.91421 5.55098 2.76987C6.11854 2.4828 6.7888 2.4828 7.35636 2.76987C7.64174 2.91421 7.90747 3.17993 8.43891 3.71138L8.63378 3.90625C8.98338 4.25585 9.15819 4.43065 9.27247 4.60643C9.70347 5.26932 9.70347 6.1239 9.27247 6.78679C9.15819 6.96257 8.98338 7.13738 8.63378 7.48698C8.51947 7.60129 8.46231 7.65845 8.41447 7.72526C8.24446 7.96269 8.18576 8.30695 8.26748 8.5873C8.29048 8.6662 8.32041 8.72854 8.38028 8.85323Z" stroke="'.$this->icon_btn_text_color.'" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/></svg>');

	 		} else if($this->agent_layout === 'Icon 8'){

	 			$this->firecall_icon_wise_html_func('call_button_lyt_8', '<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M14.0497 6C15.0264 6.19057 15.924 6.66826 16.6277 7.37194C17.3314 8.07561 17.8091 8.97326 17.9997 9.95M14.0497 2C16.0789 2.22544 17.9713 3.13417 19.4159 4.57701C20.8606 6.01984 21.7717 7.91101 21.9997 9.94M10.2266 13.8631C9.02506 12.6615 8.07627 11.3028 7.38028 9.85323C7.32041 9.72854 7.29048 9.66619 7.26748 9.5873C7.18576 9.30695 7.24446 8.96269 7.41447 8.72526C7.46231 8.65845 7.51947 8.60129 7.63378 8.48698C7.98338 8.13737 8.15819 7.96257 8.27247 7.78679C8.70347 7.1239 8.70347 6.26932 8.27247 5.60643C8.15819 5.43065 7.98338 5.25585 7.63378 4.90624L7.43891 4.71137C6.90747 4.17993 6.64174 3.91421 6.35636 3.76987C5.7888 3.4828 5.11854 3.4828 4.55098 3.76987C4.2656 3.91421 3.99987 4.17993 3.46843 4.71137L3.3108 4.86901C2.78117 5.39863 2.51636 5.66344 2.31411 6.02348C2.08969 6.42298 1.92833 7.04347 1.9297 7.5017C1.93092 7.91464 2.01103 8.19687 2.17124 8.76131C3.03221 11.7947 4.65668 14.6571 7.04466 17.045C9.43264 19.433 12.295 21.0575 15.3284 21.9185C15.8928 22.0787 16.1751 22.1588 16.588 22.16C17.0462 22.1614 17.6667 22 18.0662 21.7756C18.4263 21.5733 18.6911 21.3085 19.2207 20.7789L19.3783 20.6213C19.9098 20.0898 20.1755 19.8241 20.3198 19.5387C20.6069 18.9712 20.6069 18.3009 20.3198 17.7333C20.1755 17.448 19.9098 17.1822 19.3783 16.6508L19.1835 16.4559C18.8339 16.1063 18.6591 15.9315 18.4833 15.8172C17.8204 15.3862 16.9658 15.3862 16.3029 15.8172C16.1271 15.9315 15.9523 16.1063 15.6027 16.4559C15.4884 16.5702 15.4313 16.6274 15.3644 16.6752C15.127 16.8453 14.7828 16.904 14.5024 16.8222C14.4235 16.7992 14.3612 16.7693 14.2365 16.7094C12.7869 16.0134 11.4282 15.0646 10.2266 13.8631Z" stroke="'.$this->icon_btn_text_color.'" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/></svg>');

	 		} else if($this->agent_layout === 'Icon 9'){

	 			$this->firecall_icon_wise_html_func('call_button_lyt_9', '<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><g clip-path="url(#clip0_7_131)"><path d="M13 8C13.7956 8 14.5587 8.31607 15.1213 8.87868C15.6839 9.44129 16 10.2044 16 11C16 11.2652 16.1054 11.5196 16.2929 11.7071C16.4804 11.8946 16.7348 12 17 12C17.2652 12 17.5196 11.8946 17.7071 11.7071C17.8946 11.5196 18 11.2652 18 11C18 9.67392 17.4732 8.40215 16.5355 7.46447C15.5979 6.52678 14.3261 6 13 6C12.7348 6 12.4804 6.10536 12.2929 6.29289C12.1054 6.48043 12 6.73478 12 7C12 7.26522 12.1054 7.51957 12.2929 7.70711C12.4804 7.89464 12.7348 8 13 8V8Z" fill="'.$this->icon_btn_text_color.'"/><path d="M13 4C14.8565 4 16.637 4.7375 17.9497 6.05025C19.2625 7.36301 20 9.14348 20 11C20 11.2652 20.1054 11.5196 20.2929 11.7071C20.4804 11.8946 20.7348 12 21 12C21.2652 12 21.5196 11.8946 21.7071 11.7071C21.8946 11.5196 22 11.2652 22 11C22 8.61305 21.0518 6.32387 19.364 4.63604C17.6761 2.94821 15.3869 2 13 2C12.7348 2 12.4804 2.10536 12.2929 2.29289C12.1054 2.48043 12 2.73478 12 3C12 3.26522 12.1054 3.51957 12.2929 3.70711C12.4804 3.89464 12.7348 4 13 4V4Z" fill="'.$this->icon_btn_text_color.'"/><path d="M21.75 15.91C21.695 15.7495 21.6 15.6056 21.4741 15.4919C21.3481 15.3781 21.1953 15.2984 21.03 15.26L15.03 13.89C14.8671 13.8531 14.6976 13.8575 14.5369 13.9029C14.3762 13.9484 14.2294 14.0333 14.11 14.15C13.97 14.28 13.96 14.29 13.31 15.53C11.1532 14.5362 9.42499 12.8009 8.44 10.64C9.71 10 9.72 10 9.85 9.85C9.96671 9.73056 10.0516 9.58379 10.0971 9.42308C10.1425 9.26238 10.1469 9.09286 10.11 8.93L8.74 3C8.70165 2.8347 8.62186 2.68187 8.50814 2.55591C8.39443 2.42995 8.25053 2.335 8.09 2.28C7.85647 2.19659 7.61531 2.1363 7.37 2.1C7.11725 2.0414 6.85933 2.0079 6.6 2C5.38 2 4.20998 2.48464 3.34731 3.34731C2.48464 4.20998 2 5.38 2 6.6C2.00529 10.6827 3.62949 14.5967 6.5164 17.4836C9.40331 20.3705 13.3173 21.9947 17.4 22C18.0041 22 18.6022 21.881 19.1603 21.6498C19.7184 21.4187 20.2255 21.0798 20.6527 20.6527C21.0798 20.2255 21.4187 19.7184 21.6498 19.1603C21.881 18.6022 22 18.0041 22 17.4C22.0003 17.1455 21.9802 16.8913 21.94 16.64C21.898 16.3916 21.8344 16.1474 21.75 15.91V15.91ZM17.4 20C13.8469 19.9974 10.4401 18.5847 7.92769 16.0723C5.41528 13.5599 4.00265 10.1531 4 6.6C4.00263 5.91125 4.27741 5.25146 4.76443 4.76443C5.25146 4.27741 5.91125 4.00263 6.6 4H6.93L8 8.64L7.46 8.92C6.6 9.37 5.92 9.73 6.28 10.51C6.86622 12.1696 7.81477 13.6777 9.05674 14.9249C10.2987 16.172 11.8029 17.1269 13.46 17.72C14.3 18.06 14.63 17.43 15.08 16.56L15.37 16.01L20 17.07V17.4C19.9974 18.0888 19.7226 18.7485 19.2356 19.2356C18.7485 19.7226 18.0888 19.9974 17.4 20V20Z" fill="'.$this->icon_btn_text_color.'"/></g><defs><clipPath id="clip0_7_131"><rect width="24" height="24" fill="'.$this->icon_btn_text_color.'"/></clipPath></defs></svg>');

	 		} else if($this->agent_layout === 'Icon 10'){ 

	 			$this->firecall_icon_wise_html_func('call_button_lyt_10', '<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg"><g clip-path="url(#clip0_7_138)"><path d="M17.4 22C13.3173 21.9947 9.40331 20.3705 6.5164 17.4836C3.62949 14.5967 2.00529 10.6827 2 6.6C2 5.38 2.48464 4.20998 3.34731 3.34731C4.20998 2.48464 5.38 2 6.6 2C6.85834 1.99803 7.11625 2.02148 7.37 2.07C7.61531 2.1063 7.85647 2.16659 8.09 2.25C8.25425 2.30763 8.40061 2.40713 8.51461 2.53867C8.62861 2.67021 8.7063 2.82923 8.74 3L10.11 9C10.1469 9.16286 10.1425 9.33238 10.0971 9.49308C10.0516 9.65379 9.96671 9.80056 9.85 9.92C9.72 10.06 9.71 10.07 8.48 10.71C9.46499 12.8709 11.1932 14.6062 13.35 15.6C14 14.36 14.01 14.35 14.15 14.22C14.2694 14.1033 14.4162 14.0184 14.5769 13.9729C14.7376 13.9275 14.9071 13.9231 15.07 13.96L21.07 15.33C21.2353 15.3684 21.3881 15.4481 21.5141 15.5619C21.64 15.6756 21.735 15.8195 21.79 15.98C21.8744 16.2174 21.938 16.4616 21.98 16.71C22.0202 16.9613 22.0403 17.2155 22.04 17.47C22.0216 18.6848 21.5233 19.8429 20.654 20.6917C19.7847 21.5404 18.6149 22.0107 17.4 22ZM6.6 4C5.91125 4.00263 5.25146 4.27741 4.76443 4.76443C4.27741 5.25146 4.00263 5.91125 4 6.6C4.00265 10.1531 5.41528 13.5599 7.92769 16.0723C10.4401 18.5847 13.8469 19.9974 17.4 20C18.0888 19.9974 18.7485 19.7226 19.2356 19.2356C19.7226 18.7485 19.9974 18.0888 20 17.4V17.07L15.36 16L15.07 16.55C14.62 17.42 14.29 18.05 13.45 17.71C11.7929 17.1169 10.2887 16.162 9.04673 14.9149C7.80477 13.6677 6.85622 12.1596 6.27 10.5C5.91 9.72 6.59 9.36 7.45 8.91L8 8.64L6.93 4H6.6Z" fill="'.$this->icon_btn_text_color.'"/></g><defs><clipPath id="clip0_7_138"><rect width="24" height="24" fill="'.$this->icon_btn_text_color.'"/></clipPath></defs></svg>');
	 		}

	 		?>

	 	</div>

	 	<?php 

	 	echo ob_get_clean();
	 }


	/**
	* Define constants
	*
	* @since 1.0.0
	*/

	public function firecall_icon_wise_html_func($class, $svg) {
		?>
		<div class="call_button  <?php 
		echo esc_attr($class.' ');
		echo ($this->call_text_enable === 'unable' && $this->call_icon_enable === 'unable')?esc_attr('firecall_text_icon_enabled'):''; 
		echo ($this->call_text_enable === 'unable' && $this->call_icon_enable != 'unable')?esc_attr('firecall_text_enabled'):''; 
	?>">
	<div class="call_button_wrapper">
		<div class="call_button_svg <?php echo $this->call_layout; ?>"> 
			<?php 
			if(($this->call_icon_enable === 'unable') || ($this->call_icon_enable != 'unable' && $this->call_text_enable != 'unable')){
				?>
				<div class="fc_svg_wrapper">
					<?php echo $svg; ?>
				</div>
				<?php
			}
			if($this->call_text_enable === 'unable'){ 
				?>
				<div class="call_button_desc"><h2><?php echo $this->call_btn_text; ?></h2></div>
				<?php
			} 
			?>
		</div>
	</div>
	<?php $this->firecall_agent_listing_func(); ?>
</div>
<?php
}


	/**
	* Define constants
	*
	* @since 1.0.0
	*/

	public function firecall_agent_listing_func() {

		?>
		<div class="call_button_cross_svg">
			<div class="call_button_svg call_button_close_svg <?php echo $this->call_layout; ?>" data-color="<?php echo $this->fill_color;
		?>">
		<svg width="40" height="40" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
			<path d="M7.75732 7.75732L16.2426 16.2426" stroke="<?php echo $this->icon_btn_text_color; ?>" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
				<path d="M7.75739 16.2426L16.2427 7.75732" stroke="<?php echo $this->icon_btn_text_color; ?>" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
				</svg>
			</div>	
		</div>

		<?php

		if(isset($this->agent_lists) && is_array($this->agent_lists) && count($this->agent_lists) > 1){
			
			$this->add_firecall_agent_list_html_func();
			
		} else if(isset($this->agent_lists) && is_array($this->agent_lists) && (count($this->agent_lists) === 1) ){

			$this->add_firecall_agent_list_html_func('single_agent');
		}
	}

	 /**
 	 * Enqueue a script with jQuery as a dependency.
 	 */
	 public function add_firecall_agent_list_html_func($single = '') {
	 	ob_start();

	 	echo '<div class="agent_right_block '.esc_attr($single).'">';
	 	foreach($this->agent_lists as $agent_list){

					// variables for agent data

	 		$fc_agent_thumb = ($agent_list['firecall_ar_image'])?:'';
	 		$fc_agent_name = ($agent_list['firecall_ar_name'])?:'';
	 		$fc_agent_position = ($agent_list['firecall_ar_position'])?:'';
	 		$fc_agent_desc = ($agent_list['firecall_ar_description'])?:'';
	 		$fc_agent_telephone = ($agent_list['firecall_ar_telephone'])?:'';

	 		?>
	 		<div class="agent_wrapper">
	 			<div class="agent_image_wrapper">
	 				<img class="agent_image_content <?php echo $this->call_layout; ?>" src="<?php echo $fc_agent_thumb; ?>" alt="<?php echo $fc_agent_name; ?>">
	 			</div>
	 			<div class="agent_detail_wrapper">
	 				<div class="agent_detail_box agent_detail_box_lyt_<?php echo $this->agent_card_layout; ?>">
	 					<?php

	 					if( ( ($this->agent_card_layout == 4) || ($this->agent_card_layout == 5) || ($this->agent_card_layout == 6) ) && ( ($this->fc_agent_thumb_enable === 'unable') || ($this->fc_agent_name_enable === 'unable') || ($this->fc_agent_position_enable === 'unable') ) ){

	 						echo '<div class="agent_img_name_position_wrapper agent_layout-'.$this->agent_card_layout.'">';

	 					}

	 					if($this->fc_agent_thumb_enable === 'unable'){

	 						echo '<div class="agent_about agent_image"><img class="agent_image" src="'.$fc_agent_thumb.'" alt="'.$fc_agent_name.'"></div>';

	 					}

	 					if($this->fc_agent_name_enable === 'unable'){

	 						echo '<div class="agent_about agent_name"><h2>'.$fc_agent_name.'</h2></div>';

	 					}

	 					if($this->fc_agent_position_enable === 'unable'){

	 						echo '<div class="agent_about agent_position agent_border_lyt_4"><h3>'.$fc_agent_position.'</h3></div>';

	 					}

	 					if( ( ($this->agent_card_layout == 4) || ($this->agent_card_layout == 5) || ($this->agent_card_layout == 6) ) && ( (esc_attr($fc_agent_thumb_enable) === 'unable') || ($this->fc_agent_name_enable === 'unable') || ($this->fc_agent_position_enable === 'unable') ) ){

	 						echo '</div>';

	 					}
	 					?>
	 					<div class="agent_desc_button_wrapper">

	 						<?php

	 						if($this->fc_agent_desc_enable === 'unable'){
	 							echo '<div class="agent_bottom_detail agent_description"><p>'.$fc_agent_desc.'</p></div>';
	 						}

	 						?>

	 						<div class="agent_bottom_detail agent_detail_call_button">

	 							<div class="agent_detail_call_icon" data-color="<?php echo $this->agent_telephone_color; ?>">
	 							</div>

	 							<div class="agent_detail_contact_number">
	 								<a href="tel:<?php echo $fc_agent_telephone; ?>"><?php echo $fc_agent_telephone; ?></a>
	 							</div>

	 						</div>

	 					</div>

	 					<div class="agent_top_color_lyt_2"></div>
	 					<div class="agent_top_color_lyt_3"></div>
	 					<div class="agent_top_color_lyt_5"></div>
	 					<div class="agent_top_color_lyt_6"></div>

	 				</div> 

	 			</div>

	 		</div>
	 		<?php
	 	}
	 	echo '</div>';
	 	echo ob_get_clean();
	 }

	 /**
 	 * Enqueue a script with jQuery as a dependency.
 	 */
	 public function add_firecall_custom_style_func() {
	 	ob_start();
	 	?>
	 	<style type="text/css">
	 		<?php if(($this->fc_agent_thumb_enable === 'unable') && ( ($this->agent_card_layout == 2) || ($this->agent_card_layout == 3) )  ){ ?>

	 			.agent_detail_box.agent_detail_box_lyt_2::after, .agent_detail_box.agent_detail_box_lyt_3::after {
	 				content: "";
	 				width: 100%;
	 				height: 60px;
	 				border-radius: 10px 10px 0px 0px;
	 				position: absolute;
	 				top: 0;
	 				left: 0;
	 				z-index: -1;
	 			}
	 			.agent_detail_box.agent_detail_box_lyt_2::after{
	 				background-color: <?php echo $this->fill_color.'19'; ?>;

	 			}
	 			.agent_detail_box.agent_detail_box_lyt_3::after {
	 				background-color: #FFFFFF;
	 			}

	 		<?php } ?>

	 		.call_button_desc h2{
	 			color:  <?php echo $this->icon_btn_text_color; ?>;
	 		}

	 		<?php if(($this->fill_stroke === 'unable')){ ?>
	 			.call_button_svg {
	 				background-color: <?php echo $this->fill_color; ?>
	 			}
	 		<?php } else { ?>
	 			.call_button_svg {
	 				border: 2px solid <?php echo $this->fc_stroke_color; ?>;
	 			}
	 		<?php } ?>
	 		.agent_about.agent_name h2{
	 			color: <?php echo $this->agent_name_color; ?>;
	 		}
	 		.agent_about.agent_position h3 {
	 			color: <?php echo $this->agent_position_color; ?>;
	 		}
	 		.agent_detail_contact_number a{
	 			color: <?php echo $this->agent_telephone_color; ?>;
	 		}
	 		.agent_bottom_detail.agent_description p{
	 			color: <?php echo $this->agent_desc_color; ?>;

	 		}
	 		.agent_detail_box.agent_detail_box_lyt_3,
	 		.agent_detail_box.agent_detail_box_lyt_4 {
	 			background-color: <?php echo $this->fill_color; ?>;
	 		}
	 		.agent_img_name_position_wrapper.agent_layout-5,
	 		.agent_img_name_position_wrapper.agent_layout-6 {
	 			background-color: <?php echo $this->fill_color; ?>;
	 		}
	 		.agent_img_name_position_wrapper.agent_layout-4:after {
	 			content: "";
	 			width: 100%;
	 			height: 2px;
	 			background-color: <?php echo $this->agent_telephone_color.'99'; ?>;
	 			position: absolute;
	 			bottom: 0;
	 			left: 0;
	 		}

	 	</style>
	 	<?php
	 	echo ob_get_clean();
	 }


	/**
	* Define constants
	*
	* @since 1.0.0
	*/

	public function firecall_maybe_define_constant( $name, $value ) {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	* Set nocache constants
	*
	* @since 1.0.0
	*/
	public function firecall_set_nocache_constants() {
		$this->firecall_maybe_define_constant( 'DONOTCACHEPAGE', true );
		$this->firecall_maybe_define_constant( 'DONOTCACHEOBJECT', true );
		$this->firecall_maybe_define_constant( 'DONOTCACHEDB', true );
		$this->firecall_maybe_define_constant( 'DONOTMINIFY', true );
		$this->firecall_maybe_define_constant( 'DONOTCDN', true );
	}
}


new Firecall_Public();